import random

supported_languages = [
    "eng",
    "ita"
]


class PickupLine(object):
    """

    """
    def __init__(self):

        self._load_data()

    def _load_data(self):

        for language in supported_languages:
            filename = 'API/pickup_line/{}/pickup_line_sentences.txt'.format(language.upper())
            var_valor = []
            with open(filename) as file:
                for line in file:
                    var_valor.append(line)
                var_name = 'pickup_line_sentences_{}'.format(language.upper())
                setattr(self, var_name, var_valor)

    @staticmethod
    def _random_between(n_min, n_max):

        if n_min == n_max:
            return n_min

        return int(random.random() * (n_max - n_min) + n_min)

    def pickup_sentence(self, language, number=None, random=True):

        sentences_vector = getattr(self, 'pickup_line_sentences_{}'.format(language.upper()))

        if number is None:
            sentence_number = self._random_between(0, len(sentences_vector)-1)
        else:
            sentence_number = number - 1

        output = 'PICKUP LINE - {}:\n'.format(sentence_number + 1)
        output += sentences_vector[sentence_number]

        return output



import os
from random import randrange
from enum import Enum

full_copy_path = os.path.dirname(__file__)
filename = '{}/words/base.txt'.format(full_copy_path)

words = []
with open(filename) as file:
    for idx, line in enumerate(file.readlines()):
        words.append(line[:-1])
len_words = len(words)


class Gender(Enum):
    male = 1
    female = 2


class GenderConversion:
    male = 'o'
    female = 'a'


genders = {
    'dio': Gender.male,
    'madonna': Gender.female,
    'gesù': Gender.male,
    'allah': Gender.male,
    'puttana': Gender.female
}
len_genders = len(genders)
triggers = list(genders.keys())


class BadWordsGenerator(object):

    @staticmethod
    def __format_word(word: str, gender: Gender):
        if gender == Gender.male:
            return word.replace('%%%', GenderConversion.male)
        if gender == Gender.female:
            return word.replace('%%%', GenderConversion.female)

    def generate_sentence(self, language, character=None, gender=None):

        # generate a random number to pick a random sentence
        sn = randrange(0, len_words - 1)

        # if there is no gender
        if not character:
            i = randrange(0, len_genders - 1)
            s = triggers[i]
            return '{} {}'.format(s, self.__format_word(words[sn], genders.get(s)))

        # read the gender from the dictionary
        elif character in triggers:
            return '{} {}'.format(character, self.__format_word(words[sn], genders.get(character)))

        else:
            if not gender:
                gender = Gender.male

            return '{} {}'.format(character, self.__format_word(words[sn], gender))

    def message_reply(self, language, text):
        text_list = text.split(' ')
        for trigger in triggers:
            if trigger in text_list:
                return self.generate_sentence(language, character=trigger)



from pvlv_interactions.generators.bad_words_generator.bad_words_generator import BadWordsGenerator
from pvlv_interactions.configurations.configuration import ANALYZE_MAX_LENGTH


class Interactions(object):

    def __init__(self, text, language):
        self.in_text = text
        self.language = language

    def response(self):
        # don't analyze long messages
        if len(self.in_text) > ANALYZE_MAX_LENGTH:
            return None

        output = ''

        bwg = BadWordsGenerator()
        output += bwg.message_reply(self.language, self.in_text)

        return output


if __name__ == '__main__':
    i = Interactions('ciao dio cane', 'ita')
    out = i.response()
    print(out)



from setuptools import setup, find_packages

with open('README.md', 'r') as fh:
    long_description = fh.read()

packages = find_packages(exclude=['tests*'])

setup(
    name='pvlv_interactions',
    version='0.0.1',
    license='LGPLv3',

    author='AbbestiaDC',
    author_email='not.simone.scuola@outlook.com',
    description='Natural language processing for Pavlov',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/The-Pavlov-Project/Pavlov-Interactions',

    packages=packages,
    include_package_data=True,

    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],

    python_requires='>=3.6',
    install_requires=[
    ],
)



import configparser as cfg
import logging


CONFIG_PATH = 'configs/interactions.cfg'

parser = cfg.ConfigParser()
try:
    parser.read(CONFIG_PATH)
except Exception as exc:
    print(exc)

ANALYZE_MAX_LENGTH = parser.get('text', 'ANALYZE_MAX_LENGTH', fallback=30)

DEBUG = parser.get('debug', 'DEBUG', fallback=False)

logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger('pvlv_commando')

if DEBUG:
    logger.setLevel(logging.INFO)
else:
    logger.setLevel(logging.ERROR)



import random

CHUCK_NORRIS = "Chuck Norris"
JOHN_WICK = "John Wick"


supported_languages = [
    "eng",
    "ita"
]


class BadassCharacter(object):

    def __init__(self):

        self._load_data()

    def _load_data(self):

        for language in supported_languages:
            filename = 'API/badass_character/{}/badass_sentences.txt'.format(language.upper())
            var_valor = []
            with open(filename) as file:
                for line in file:
                    var_valor.append(line)
                var_name = 'badass_sentences_{}'.format(language.upper())
                setattr(self, var_name, var_valor)

    @staticmethod
    def _random_between(n_min, n_max):

        if n_min == n_max:
            return n_min

        return int(random.random() * (n_max - n_min) + n_min)

    def badass_sentence(self, language, character, number=None):

        sentences_vector = getattr(self, 'badass_sentences_{}'.format(language.upper()))

        if number is None:
            sentence_number = self._random_between(0, len(sentences_vector)-1)
        else:
            sentence_number = number - 1

        output = '{} - {}:\n'.format(character.upper(), sentence_number + 1)
        output += sentences_vector[sentence_number].replace('%%%', character.title())

        return output
